(self.webpackChunkpp_label_frontend=self.webpackChunkpp_label_frontend||[]).push([[124],{91220:function(d,i,t){"use strict";t.d(i,{Z:function(){return c}});var f=t(64254);function c(r,O){var e;if(typeof Symbol=="undefined"||r[Symbol.iterator]==null){if(Array.isArray(r)||(e=(0,f.Z)(r))||O&&r&&typeof r.length=="number"){e&&(r=e);var a=0,l=function(){};return{s:l,n:function(){return a>=r.length?{done:!0}:{done:!1,value:r[a++]}},e:function(P){throw P},f:l}}throw new TypeError(`Invalid attempt to iterate non-iterable instance.
In order to be iterable, non-array objects must have a [Symbol.iterator]() method.`)}var o=!0,E=!1,n;return{s:function(){e=r[Symbol.iterator]()},n:function(){var P=e.next();return o=P.done,P},e:function(P){E=!0,n=P},f:function(){try{!o&&e.return!=null&&e.return()}finally{if(E)throw n}}}}},41435:function(d,i,t){"use strict";t.d(i,{Z:function(){return a}});var f=t(94663),c=t(80112);function r(l){return Function.toString.call(l).indexOf("[native code]")!==-1}var O=t(18597);function e(l,o,E){return(0,O.Z)()?e=Reflect.construct:e=function(_,P,s){var u=[null];u.push.apply(u,P);var M=Function.bind.apply(_,u),m=new M;return s&&(0,c.Z)(m,s.prototype),m},e.apply(null,arguments)}function a(l){var o=typeof Map=="function"?new Map:void 0;return a=function(n){if(n===null||!r(n))return n;if(typeof n!="function")throw new TypeError("Super expression must either be null or a function");if(typeof o!="undefined"){if(o.has(n))return o.get(n);o.set(n,_)}function _(){return e(n,arguments,(0,f.Z)(this).constructor)}return _.prototype=Object.create(n.prototype,{constructor:{value:_,enumerable:!1,writable:!0,configurable:!0}}),(0,c.Z)(_,n)},a(l)}},41180:function(d){d.exports={ppcard:"ppcard___27hGd",title:"title___22R8f"}},70362:function(d){d.exports={card:"card___CFZWU",thumbnail:"thumbnail___1gIPM",button:"button___g0lkO"}},48627:function(d){d.exports={container:"container___2RXc3"}},17969:function(d){d.exports={col:"col___yKN-b"}},31982:function(d,i,t){"use strict";var f=t(89032),c=t(15746),r=t(11849),O=t(13062),e=t(71230),a=t(11700),l=t(67294),o=t(41180),E=t.n(o),n=t(85893),_=function(s){return(0,n.jsxs)("div",{className:E().ppcard,style:s.style,hidden:s.hidden,children:[(0,n.jsx)(e.Z,{className:E().titleRow,style:{display:s.title?void 0:"none"},children:(0,n.jsx)(a.Z,{className:E().title,children:s.title})}),(0,n.jsx)(e.Z,{style:{marginTop:26},children:(0,n.jsx)(c.Z,{span:24,style:(0,r.Z)({paddingLeft:30,paddingRight:30,textAlign:"center"},s.innerStyle),children:s.children})})]})};i.Z=_},40318:function(d,i,t){"use strict";var f=t(57663),c=t(71577),r=t(48971),O=t(67294),e=t(70362),a=t.n(e),l=t(85893),o=function(n){return(0,l.jsxs)("div",{className:a().card,style:{height:n.height,width:n.width},onClick:n.onClick?n.onClick:function(){return r.m8.push(n.href?n.href:"")},children:[(0,l.jsx)("img",{className:a().thumbnail,alt:n.wording||a().thumbnail,src:n.imgSrc,style:{height:n.height,width:n.width}}),(0,l.jsx)(c.Z,{className:a().button,style:{width:n.width},children:n.children})]})};i.Z=o},11428:function(d,i,t){"use strict";var f=t(67294),c=t(48627),r=t.n(c),O=t(85893),e=function(l){return(0,O.jsx)("div",{className:"".concat(r().container),style:{backgroundImage:"url(./pics/background.png)"},children:l.children})};i.Z=e},52940:function(d,i,t){"use strict";var f=t(11849),c=t(89032),r=t(15746),O=t(2824),e=t(67294),a=t(17969),l=t.n(a),o=t(85893),E=function(_){var P=(0,e.useState)(!1),s=(0,O.Z)(P,2),u=s[0],M=s[1];return(0,o.jsx)(r.Z,(0,f.Z)((0,f.Z)({},_),{},{className:"".concat(l().col," ").concat(_.className),style:{zIndex:u?11:10,width:"100%"},onMouseOver:function(){M(!0)},onMouseLeave:function(){M(!1)},children:_.children}))};i.Z=E},64873:function(d,i,t){"use strict";t.r(i);var f=t(89032),c=t(15746),r=t(13062),O=t(71230),e=t(34792),a=t(48086),l=t(67294),o=t(48971),E=t(40318),n=t(31982),_=t(11428),P=t(52940),s=t(47704),u=t(85893),M=function(){var D=(0,s.Ad)("pages.welcome");return(0,u.jsx)(_.Z,{children:(0,u.jsx)(O.Z,{style:{marginTop:20},children:(0,u.jsx)(c.Z,{span:24,children:(0,u.jsx)(n.Z,{style:{height:500},title:D("sampleProject"),children:(0,u.jsx)(O.Z,{children:Object.entries(s.ux).map(function(I){var v=I[0],h=I[1];return console.log("asdf",v,h),(0,u.jsx)(P.Z,{span:4,children:(0,u.jsx)(E.Z,{height:360,width:310,imgSrc:h.avatar,onClick:v!="keypointDetection"?function(){s.dG.loadSample({taskCategoryId:h.id}).then(function(C){o.m8.push("/project_overview?projectId=".concat(C.projectId))})}:function(){a.default.info(D("underDevelopment","global"))},children:D(v,"global")})},v)})})})})})})};i.default=M}}]);
