(self.webpackChunkpp_label_frontend=self.webpackChunkpp_label_frontend||[]).push([[571],{91562:function(u,_,t){"use strict";t.r(_);var l=t(57106),s=t(99683),P=t(57663),E=t(71577),e=t(67294),a=t(48971),n=t(85893),o=function(){return(0,n.jsx)(s.ZP,{status:"404",title:"404",subTitle:"Sorry, the page you visited does not exist.",extra:(0,n.jsx)(E.Z,{type:"primary",onClick:function(){return a.m8.push("/")},children:"Back Home"})})};_.default=o}}]);
