(self.webpackChunkpp_label_frontend=self.webpackChunkpp_label_frontend||[]).push([[540],{41435:function(w,l,r){"use strict";r.d(l,{Z:function(){return c}});var v=r(94663),p=r(80112);function d(o){return Function.toString.call(o).indexOf("[native code]")!==-1}var y=r(18597);function u(o,e,s){return(0,y.Z)()?u=Reflect.construct:u=function(n,b,f){var i=[null];i.push.apply(i,b);var h=Function.bind.apply(n,i),a=new h;return f&&(0,p.Z)(a,f.prototype),a},u.apply(null,arguments)}function c(o){var e=typeof Map=="function"?new Map:void 0;return c=function(t){if(t===null||!d(t))return t;if(typeof t!="function")throw new TypeError("Super expression must either be null or a function");if(typeof e!="undefined"){if(e.has(t))return e.get(t);e.set(t,n)}function n(){return u(t,arguments,(0,v.Z)(this).constructor)}return n.prototype=Object.create(t.prototype,{constructor:{value:n,enumerable:!1,writable:!0,configurable:!0}}),(0,p.Z)(n,t)},c(o)}}}]);
